@@ -9,6 +9,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
                     level=0.95, level.comb=level,
                     comb.fixed=TRUE, comb.random=TRUE,
                     title="", complab="", outclab="",
+                    label.e="Experimental", label.c="Control",
                     byvar, bylab, print.byvar=TRUE,
                     warn=TRUE
                     ){
@@ -489,6 +490,8 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
               title=title,
               complab=complab,
               outclab=outclab,
+              label.e=label.e,
+              label.c=label.c,
               call=match.call(),
               warn=warn)
   ##
