@@ -1,6 +1,7 @@
 print.meta <- function(x,
                        sortvar,
                        level=x$level, level.comb=x$level.comb,
+                       comb.fixed=x$comb.fixed, comb.random=x$comb.random,
                        details=FALSE, ma=TRUE,
                        digits=max(4, .Options$digits - 3),
                        ...
@@ -47,8 +48,8 @@ print.meta <- function(x,
     else res <- ifelse(is.na(TE), "", format(TE))
     res
   }
-
-
+  
+  
   k.all <- length(x$TE)
   ##
   if (missing(sortvar)) sortvar <- 1:k.all
@@ -57,17 +58,27 @@ print.meta <- function(x,
     stop("'x' and 'sortvar' have different length")
   
   
+  if (length(comb.fixed)==0){
+    comb.fixed <- TRUE
+  }
+  ##
+  if (length(comb.random)==0){
+    comb.random <- TRUE
+  }
+  
+  
   if (length(level)==0){
     warning("level set to 0.95")
     level <- 0.95
   }
   ##
   if (length(level.comb)==0){
-    ##if (comb.fixed | comb.random)
-    warning("level.comb set to 0.95")
+    if (comb.fixed | comb.random)
+      warning("level.comb set to 0.95")
     level.comb <- 0.95
   }
   
+  
   ci.lab <- paste(round(100*level, 1), "%-CI", sep="")
 
   
@@ -100,9 +111,33 @@ print.meta <- function(x,
     prmatrix(res[order(sortvar),])
     cat("\n\n")
   }
-
-
-
+  
+  
+  tl <- options()$width-12
+  ##
+  if (!is.null(x$title))
+    if (x$title!="")
+      if (nchar(x$title) <= tl)
+        cat("Review:     ", x$title, "\n", sep="")
+      else
+        cat("Review:     ", substring(x$title, 1, tl-4),
+            " ...\n", sep="")
+  if (!is.null(x$complab))
+    if (x$complab!="")
+      if (nchar(x$complab) <= tl)
+        cat("Comparison: ", x$complab, "\n", sep="")
+      else
+        cat("Comparison: ", substring(x$complab, 1, tl-4),
+            " ...\n", sep="")
+  if (!is.null(x$outclab))
+    if (x$outclab!="")
+      if (nchar(x$outclab) <= tl)
+        cat("Outcome:    ", x$outclab, "\n\n", sep="")
+      else
+        cat("Outcome:    ", substring(x$outclab, 1, tl-4),
+            " ...\n\n", sep="")
+  
+  
   if (k.all == 1 & !inherits(x, "metaprop")){
     if (inherits(x, "metabin") & x$method=="MH")
       print(summary(metabin(x$event.e, x$n.e,
@@ -115,9 +150,10 @@ print.meta <- function(x,
                             allstudies=x$allstudies,
                             MH.exact=x$MH.exact,
                             warn=FALSE), level.comb=level.comb),
-            digits=digits)
+            digits=digits, header=FALSE)
     else
-      print(summary(x, level.comb=level.comb), digits=digits)
+      print(summary(x, level.comb=level.comb),
+            digits=digits, header=FALSE)
   }
   else{
     tsum <- summary(x, level=level, level.comb=level.comb, warn=FALSE)
@@ -136,13 +172,15 @@ print.meta <- function(x,
     lowTE <- round(lowTE, digits)
     uppTE <- round(uppTE, digits)
     
-    if (sum(x$w.fixed)>0)
-     w.fixed.p <- 100*round(x$w.fixed/sum(x$w.fixed, na.rm=TRUE), 4)
-    else w.fixed.p <- x$w.fixed
-
-    if (sum(x$w.random)>0)
-     w.random.p <- 100*round(x$w.random/sum(x$w.random, na.rm=TRUE), 4)
-    else w.random.p <- x$w.random
+    if (comb.fixed)
+      if (sum(x$w.fixed)>0)
+        w.fixed.p <- 100*round(x$w.fixed/sum(x$w.fixed, na.rm=TRUE), 4)
+      else w.fixed.p <- x$w.fixed
+    
+    if (comb.random)
+      if (sum(x$w.random)>0)
+        w.random.p <- 100*round(x$w.random/sum(x$w.random, na.rm=TRUE), 4)
+      else w.random.p <- x$w.random
     
     if (inherits(x, "metainf")|inherits(x, "metacum")){
       sel1 <- is.na(x$I2)
@@ -197,20 +235,25 @@ print.meta <- function(x,
     else{
       res <- cbind(format.TE(TE, na=TRUE),
                    p.ci(format(lowTE), format(uppTE)),
-                   format(w.fixed.p), format(w.random.p))
+                   if (comb.fixed) format(w.fixed.p),
+                   if (comb.random) format(w.random.p))
       ##
       ## Printout for a single proportion:
       ##
       if (k.all==1){
         cat("Exact CI:\n\n")
         dimnames(res) <-
-          list("", c(x$sm, ci.lab, "%W(fixed)", "%W(random)"))
+          list("", c(x$sm, ci.lab,
+                     if (comb.fixed) "%W(fixed)",
+                     if (comb.random) "%W(random)"))
         prmatrix(res, quote=FALSE, right=TRUE)
         cat("\n\nCI based on arcsine transformation:\n")
       }
       else{
         dimnames(res) <-
-          list(x$studlab, c(x$sm, ci.lab, "%W(fixed)", "%W(random)"))
+          list(x$studlab, c(x$sm, ci.lab,
+                            if (comb.fixed) "%W(fixed)",
+                            if (comb.random) "%W(random)"))
         prmatrix(res[order(sortvar),], quote=FALSE, right=TRUE)
       }
       cat("\n")
@@ -218,7 +261,9 @@ print.meta <- function(x,
     
     
     if (ma&!(inherits(x, "metainf")|inherits(x, "metacum")))
-      print(tsum, digits=digits)
+      print(tsum, digits=digits,
+            comb.fixed=comb.fixed, comb.random=comb.random,
+            header=FALSE)
     
   }
   
